@@ -15,5 +15,5 @@ from .simulators import CarbonSimulatorUI
 from .simulators import sim_analytics as analytics
 
 
-__version__ = "1.3"
-__date__ = "30/Nov/2022"
+__version__ = "1.4"
+__date__ = "6/Dec/2022"
